/* Add your own colors, sizes, etc. to match the screenshot */

#sidebar {
  width: 100%;
  background-color: #333;
  color: #fff;
  padding: 20px;
}

#userInput {
  color: var(--bs-body-color);
}
#userInput:focus {
  border: none; /* Removes the border */
  outline: none; /* Removes the outline if present */
}

#chatList {
  padding: 15px;
  border-right: 1px solid #ddd;
  height: 100vh;
}

#chatList h5 {
  margin-bottom: 15px;
}

#chatList .list-group-item {
  cursor: pointer;
  transition: background-color 0.3s;
  color: var(--bs-body-color);
  background-color: var(--bs-body-bg);
}

#chatList .list-group-item:hover {
  background-color: var(--bs-light);
}

#chatList .list-group-item.active {
  background-color: var(--bs-primary);
  color: var(--bs-light);
}

#chatList .actions {
  margin-top: 15px;
}

#chatList .btn-action {
  width: 100%;
  margin-top: 5px;
}

#main-content {
  flex-direction: column;
}

#main-header {
  text-align: center;
}

#chatbox {
  flex-grow: 1;
  overflow-y: auto;
  padding-top: 40px;
}

#chat-input {
  display: flex;
  padding: 10px;
}

#chat-input input[type="text"] {
  flex-grow: 1;
  padding: 5px;
  margin-right: 5px;
}
#composer-background {
  border-radius: 1rem !important;
}

#chat-input button {
  padding: 5px 10px;
}

#chat-input input[type="file"] {
  margin-right: 5px;
}

.message {
  display: flex;
  align-items: top;
  margin-bottom: 10px;
  color: var(--bs-body-color);
}

.chatavatar {
  width: 30px;
  height: 30px;
  border-radius: 50%;
  display: flex;
  justify-content: center;
  align-items: center;
  font-weight: bold;
  margin-right: 10px;
}

.user-message .chatavatar {
  background-color: rgba(
    var(--bs-primary-rgb),
    1
  ); /* Replace with the actual color */
  color: var(--bs-body-bg);
}

.user-message .text {
  background-color: rgba(var(--bs-primary-rgb), 0.5);
  padding: 10px;
  border-radius: 10px;
  max-width: 90%;
}

.bot-message .chatavatar {
  background-color: rgba(
    var(--bs-secondary-rgb),
    1
  ); /* Replace with the actual color */
  color: var(--bs-body-bg);
}

.bot-message .text {
  background-color: rgba(var(--bs-secondary-rgb), 0.5); /* Slightly darker */
  padding: 10px;
  border-radius: 10px;
  max-width: 90%;
}

/* Style for code blocks */
pre {
  border-radius: 5px;
  overflow: auto;
  position: relative;
  background-color: var(--bs-body-bg);
}
.hljs {
  background-color: var(--bs-body-bg);
}
.copy-button {
  background: transparent;
  border: none;
  color: var(--bs-body-color);
  cursor: pointer;
  font-size: 16px;
  opacity: 0.8;
  transition: opacity 0.2s ease;
}
.copy-button:hover {
  opacity: 1;
}
